aboutsummaryrefslogtreecommitdiffstats
path: root/gtk/profile_dlg.h
diff options
context:
space:
mode:
authorStig Bjørlykke <stig@bjorlykke.org>2011-05-30 12:42:46 +0000
committerStig Bjørlykke <stig@bjorlykke.org>2011-05-30 12:42:46 +0000
commitf8425c99a6453be5be920714d0a6dc841aa9069f (patch)
tree1215a1ef4168f83f4a437ce0d6b8635a5863fe49 /gtk/profile_dlg.h
parentccd2833ad8c47d47f89b19e0a46ddf318dc52ef8 (diff)
downloadwireshark-f8425c99a6453be5be920714d0a6dc841aa9069f.tar.gz
wireshark-f8425c99a6453be5be920714d0a6dc841aa9069f.tar.bz2
wireshark-f8425c99a6453be5be920714d0a6dc841aa9069f.zip
Changed "Rename" to "Edit" in profiles popup menu.
svn path=/trunk/; revision=37469
Diffstat (limited to 'gtk/profile_dlg.h')
-rw-r--r--gtk/profile_dlg.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk/profile_dlg.h b/gtk/profile_dlg.h
index 06a5addd58..934e2c4ce7 100644
--- a/gtk/profile_dlg.h
+++ b/gtk/profile_dlg.h
@@ -53,12 +53,12 @@ void profile_new_cb (GtkWidget *w _U_, gpointer data _U_);
*/
void profile_delete_cb (GtkWidget *w _U_, gpointer data _U_);
/** User requested to rename the current profile.
*
* @param w parent widget (unused)
* @param data pointer to user_data (unused)
*/
-void profile_rename_cb (GtkWidget *w _U_, gpointer data _U_);
+void profile_edit_cb (GtkWidget *w _U_, gpointer data _U_);
/** User requested the "Configuration Profiles" dialog box by menu or toolbar.
*
@@ -53,12 +53,12 @@ void profile_new_cb (GtkWidget *w _U_, gpointer data _U_);
*/
void profile_delete_cb (GtkWidget *w _U_, gpointer data _U_);
-/** User requested to rename the current profile.
+/** User requested to edit the current profile.
*
* @param w parent widget (unused)